@@ -36,7 +36,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-$Revision$ $Date$
+$Revision: 5.102 $ $Date: 2000/05/21 07:54:10 $
 
 =cut
 
@@ -45,10 +45,10 @@ use vars qw(@ISA $VERSION);
 
 @ISA = qw(MIME::Decoder);
 
-### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.420_02";
+# The package version, both in 1.23 style *and* usable by MakeMaker:
+$VERSION = substr q$Revision: 5.102 $, 10;
 
-### Buffer length:
+# Buffer length:
 my $BUFLEN = 8192;
 
 #------------------------------
@@ -62,7 +62,7 @@ sub decode_it {
     while ($nread = $in->read($buf, $BUFLEN)) {
 	$out->print($buf);
     }
-    defined($nread) or return undef;      ### check for error
+    defined($nread) or return undef;      # check for error
     1;
 }
 
@@ -77,7 +77,7 @@ sub encode_it {
     while ($nread = $in->read($buf, $BUFLEN)) {
 	$out->print($buf);
     }
-    defined($nread) or return undef;      ### check for error
+    defined($nread) or return undef;      # check for error
     1;
 }
 
