@@ -45,24 +45,24 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-$Revision$ $Date$
+$Revision: 5.102 $ $Date: 2000/04/20 04:56:45 $
 
 =cut
 
 
 require 5.002;
-use strict;
-use vars qw(@ISA $VERSION $GZIP $GUNZIP);
+use vars qw(@ISA $VERSION $ZIP $UNZIP);
 use MIME::Decoder;
 use MIME::Base64;
 use MIME::Decoder::Base64;
 use MIME::Tools qw(tmpopen whine);
+use IO::Wrap;
 
 # Inheritance:
 @ISA = qw(MIME::Decoder::Base64);
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.420_02";
+$VERSION = substr q$Revision: 5.102 $, 10;
 
 # How to compress stdin to stdout:
 $GZIP   = "gzip -c";
@@ -79,7 +79,7 @@ sub decode_it {
     my ($self, $in, $out) = @_;
 
     # Open a temp file (assume the worst, that this is a big stream):
-    my $tmp = tmpopen() || die "can't get temp file";
+    my $tmp = wraphandle(tmpopen() || die "can't get temp file");
 
     # Stage 1: decode the base64'd stream into zipped data:
     $self->SUPER::decode_it($in, $tmp)    or die "base64 decoding failed!";
@@ -98,7 +98,7 @@ sub encode_it {
     whine "Encoding ", $self->encoding, " is not standard MIME!"; 
     
     # Open a temp file (assume the worst, that this is a big stream):
-    my $tmp = tmpopen() || die "can't get temp file";
+    my $tmp = wraphandle(tmpopen() || die "can't get temp file");
   
     # Stage 1: zip the raw data:
     $self->filter($in, $tmp, $GZIP)       or die "gzip encoding failed!";
