@@ -3,18 +3,11 @@ package MIME::Words;
 
 =head1 NAME
 
-MIME::Words - deal with RFC 2047 encoded words
+MIME::Words - deal with RFC-1522 encoded words
 
 
 =head1 SYNOPSIS
 
-Before reading further, you should see L<MIME::Tools> to make sure that 
-you understand where this module fits into the grand scheme of things.
-Go on, do it now.  I'll wait.  
-
-Ready?  Ok...
-
-
     use MIME::Words qw(:all);   
      
     ### Decode the string into another string, forgetting the charsets:
@@ -34,7 +27,6 @@ Ready?  Ok...
     $encoded = encode_mimewords("Me and \xABFran\xE7ois\xBB in town");
 
 
-
 =head1 DESCRIPTION
 
 Fellow Americans, you probably won't know what the hell this module
@@ -94,7 +86,7 @@ use MIME::QuotedPrint;
 #------------------------------
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.420_02";
+$VERSION = substr q$Revision: 5.104 $, 10;
 
 ### Nonprintables (controls + x7F + 8bit):
 my $NONPRINT = "\\x00-\\x1F\\x7F-\\xFF"; 
@@ -107,8 +99,8 @@ my $NONPRINT = "\\x00-\\x1F\\x7F-\\xFF";
 #     almost, but not exactly, quoted-printable.  :-P
 sub _decode_Q {
     my $str = shift;
-    $str =~ s/_/\x20/g;                                # RFC-1522, Q rule 2
     $str =~ s/=([\da-fA-F]{2})/pack("C", hex($1))/ge;  # RFC-1522, Q rule 1
+    $str =~ s/_/\x20/g;                                # RFC-1522, Q rule 2
     $str;
 }
 
@@ -117,7 +109,7 @@ sub _decode_Q {
 #     almost, but not exactly, quoted-printable.  :-P
 sub _encode_Q {
     my $str = shift;
-    $str =~ s{([_\?\=$NONPRINT])}{sprintf("=%02X", ord($1))}eog;
+    $str =~ s{([\?\=\_$NONPRINT])}{sprintf("=%02X", ord($1))}eog;
     $str;
 }
 
@@ -132,7 +124,7 @@ sub _decode_B {
 #     Private: used by _decode_header() to decode "B" encoding.
 sub _encode_B {
     my $str = shift;
-    encode_base64($str, '');
+    encode_base64($str);
 }
 
 
@@ -141,8 +133,7 @@ sub _encode_B {
 
 =item decode_mimewords ENCODED, [OPTS...]
 
-I<Function.>
-Go through the string looking for RFC 2047-style "Q"
+Go through the string looking for RFC-1522-style "Q"
 (quoted-printable, sort of) or "B" (base64) encoding, and decode them.
 
 B<In an array context,> splits the ENCODED string into a list of decoded 
@@ -155,12 +146,9 @@ CHARSET of C<undef>.
         print "", ($_[1] || 'US-ASCII'), ": ", $_[0], "\n";
     }
 
-B<In a scalar context,> joins the "data" elements of the above 
-list together, and returns that.  I<Warning: this is information-lossy,>
-and probably I<not> what you want, but if you know that all charsets 
-in the ENCODED string are identical, it might be useful to you.
-(Before you use this, please see L<MIME::WordDecoder/unmime>,
-which is probably what you want.)
+B<In a scalar context,> joins the "data" elements of the above list together,
+and returns that.  This is information-lossy, but if you know that
+all charsets in the ENCODED string are identical, it might be useful to you.
 
 In the event of a syntax error, $@ will be set to a description 
 of the error, but parsing will continue as best as possible (so as to
@@ -186,7 +174,7 @@ sub decode_mimewords {
     $@ = '';           ### error-return
 
     ### Collapse boundaries between adjacent encoded words:
-    $encstr =~ s{(\?\=)\s*(\=\?)}{$1$2}gs;
+    $encstr =~ s{(\?\=)\r?\n[ \t](\=\?)}{$1$2}gs;
     pos($encstr) = 0;
     ### print STDOUT "ENC = [", $encstr, "]\n";
 
@@ -241,15 +229,15 @@ sub decode_mimewords {
 
 =item encode_mimeword RAW, [ENCODING], [CHARSET]
 
-I<Function.>
 Encode a single RAW "word" that has unsafe characters.
-The "word" will be encoded in its entirety.
 
     ### Encode "<<Franc,ois>>":
     $encoded = encode_mimeword("\xABFran\xE7ois\xBB");
 
 You may specify the ENCODING (C<"Q"> or C<"B">), which defaults to C<"Q">.
 You may specify the CHARSET, which defaults to C<iso-8859-1>.
+    
+The "word" will be encoded in its entirety.
 
 =cut
 
@@ -265,7 +253,6 @@ sub encode_mimeword {
 
 =item encode_mimewords RAW, [OPTS]
 
-I<Function.>
 Given a RAW string, try to find and encode all "unsafe" sequences 
 of characters:
 
@@ -293,11 +280,8 @@ Name of the mail field this string will be used in.  I<Currently ignored.>
 =back
 
 B<Warning:> this is a quick-and-dirty solution, intended for character
-sets which overlap ASCII.  B<It does not comply with the RFC 2047
-rules regarding the use of encoded words in message headers>.
-You may want to roll your own variant,
+sets which overlap ASCII.  You may want to roll your own variant,
 using C<encoded_mimeword()>, for your application.
-I<Thanks to Jan Kasprzak for reminding me about this problem.>
 
 =cut
 
@@ -318,7 +302,6 @@ sub encode_mimewords {
     }xeg;
     $rawstr;
 }
-
 1;
 __END__
 
@@ -334,7 +317,6 @@ MIME::Base64 and MIME::QuotedPrint.
 =head1 AUTHOR
 
 Eryq (F<eryq@zeegee.com>), ZeeGee Software Inc (F<http://www.zeegee.com>).
-David F. Skoll (dfs@roaringpenguin.com) http://www.roaringpenguin.com
 
 All rights reserved.  This program is free software; you can redistribute 
 it and/or modify it under the same terms as Perl itself.
@@ -350,6 +332,58 @@ Thanks also to...
 
 =head1 VERSION
 
-$Revision$ $Date$
+$Revision: 5.104 $ $Date: 2000/05/23 05:36:20 $
 
 =cut
+
+
+#------------------------------
+# Execute simple test if run as a script.
+#------------------------------
+{ 
+  package main; no strict;
+  eval join('',<main::DATA>) || die "$@ $main::DATA" unless caller();
+}
+1;           # end the module
+__END__
+
+
+### Pick up other MIME stuff, just in case...
+BEGIN { unshift @INC, ".", "./etc", "./lib" };
+import MIME::Words;
+
+my @encs = (
+	    '=?US-ASCII?Q?Keith_Moore?= <moore@cs.utk.edu>',
+	    '=?ISO-8859-1?Q?Keld_J=F8rn_Simonsen?= <keld@dkuug.dk>',
+	    '=?ISO-8859-1?Q?Andr=E9_?= Pirard <PIRARD@vm1.ulg.ac.be>',
+	    ('=?ISO-8859-1?B?SWYgeW91IGNhbiByZWFkIHRoaXMgeW8=?='.
+	     '=?ISO-8859-2?B?dSB1bmRlcnN0YW5kIHRoZSBleGFtcGxlLg==?='.
+	     '=?US-ASCII?Q?.._cool!?='));
+foreach $enc (@encs) {
+    $x = decode_mimewords($enc);
+    print "DEC: ", $x, "\n";
+}
+
+### Encode a single unsafe word:
+$encoded = encode_mimeword("\xABFran\xE7ois\xBB");
+print "ENC1: ", $encoded, "\n";
+    
+### Encode a string, trying to find the unsafe words inside it: 
+$encoded = encode_mimewords("Me and \xABFran\xE7ois\xBB at the beach");
+print "ENC2: ", $encoded, "\n";
+
+### Encode "<<Franc,ois>>":
+my $unsafe = <<EOF;
+Me and \xABFran\xE7ois\xBB, down at the beach
+with Dave <dave\@ether.net>
+EOF
+$encoded = encode_mimewords($unsafe);
+print "ENC3: ", $encoded, "\n";
+print "DEC3: ", scalar(decode_mimewords($encoded)), "\n";
+
+### So we know everything went well...
+exit 0;
+
+#------------------------------
+
+
